## 1.17.8.1 (2022-11-06)

Remove `annoy` from pyright excludelist (#9114)

## 1.17.8 (2022-07-19)

Add missing third party modules (#8321)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: hauntsaninja <>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 1.17.7 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 1.17.6 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 1.17.4 (2021-10-12)

Add star to all non-0.1 versions (#6146)

